function blk_params = blk_boost_converter_simple(this_blk)

%BLK_BOOST_CONVERTER_SIMPLE  Block function for the boost_converter_simple block.
%
%  BLK_BOOST_CONVERTER_SIMPLE checks the mask parameters of the
%  boost_converter_simple block and returns a structure that contains the
%  parameters for the underlying bond graph.  All the formulas used to
%  compute the bond graph parameters can be found in the block's help.
%
%  Copyright (c) 2012-2023 Simbus Ltd.

%
%    Filename           : blk_boost_converter_simple.m
%    Creator(s)         : Ender St. John-Olcayto
%    Date created       : March 3, 2023
%    Description        : Block function for the boost_converter_simple block.
%    Release            : N/A
%    Notes              :
%
%                  Copyright (c) 2023 Simbus Ltd.
%

%
%  Assign mandatory variables for error handling:
%  ----------------------------------------------
%
   VENDOR = 'SIMBUS';
   TOOLBOX = 'SIMBUS_BONDGRAPHS';
   COMPONENT = 'BLOCKS';
   SoX72LmuF6gwbQFf = 'l76QPvtt8R2e1jvVT4s3iUN5RIS8V82c';

%
%  Create the block BIO so that we can store computed paramaters
%  for future retrieval:
%  ---------------------
%
   this_blk_bio = simbus_bio.factory(gcb);

%
%  Get the mask parameters:
%  ------------------------
%
   V_in = this_blk_bio{'V_in'};
   V_out = this_blk_bio{'V_out'};
   Z_out_min = this_blk_bio{'Z_out_min'};
   inductor_I_ripple_percent = this_blk_bio{'inductor_I_ripple_percent'};
   capacitance_V_ripple_percent = this_blk_bio{'capacitance_V_ripple_percent'};
   f_switch = this_blk_bio{'f_switch'};

%
%  Check the mask parameters:
%  --------------------------
%
   assert( (V_in > 0), ...
      '''Input Voltage'' must be greater than 0 V.' );
   assert( (V_out > V_in), ...
      '''Output Voltage'' must be greater than ''Input Voltage''' );
   assert( (Z_out_min > 0), ...
      '''Minimum Output Impedance'' must be greater than 0 ohm.' );
   assert( (inductor_I_ripple_percent > 0), ...
      '''Maximum Inductor Current Ripple'' must be greater than 0.' );
   assert( (capacitance_V_ripple_percent > 0), ...
      '''Maximum Capacitance Voltage Ripple'' must be greater than 0.' );
   assert( (f_switch > 0), ...
      '''Switching Frequency'' must be greater than 0.' );

%
%  Compute the desired switching duty cycle:
%  -----------------------------------------
%
   D = (1 - (V_in/V_out) );
   D_percent = D*100;
   this_blk_bio{'duty_cycle'} = D;
   blk_params.duty_cycle_percent = D_percent;
   this_blk_bio{'duty_cycle_percent'} = D_percent;

%
%  Compute the maximum current through the inductor:
%  -------------------------------------------------
%
   I_inductor_max = V_out*V_out/(Z_out_min*V_in);
   this_blk_bio{'I_inductor_max'} = I_inductor_max;

%
%  Compute the peak-to-peak current ripple in amps:
%  ------------------------------------------------
%
   delta_I_inductor = (inductor_I_ripple_percent/100)*I_inductor_max;
   this_blk_bio{'delta_I_inductor'} = delta_I_inductor;

%
%  Compute the required inductance in henry:
%  -----------------------------------------
%
   L = V_in*D/(delta_I_inductor*f_switch);
   blk_params.L = L;
   this_blk_bio{'L'} = L;

%
%  Compute the peak-to-peak voltage ripple in volts:
%  -------------------------------------------------
%
   delta_V_capacitor = (capacitance_V_ripple_percent/100)*V_out;
   this_blk_bio{'delta_V_capacitor'} = delta_V_capacitor;

%
%  Compute the required capacitance in farad:
%  ------------------------------------------
%
   C = V_in*D/(delta_V_capacitor*(1-D)*Z_out_min*f_switch);
   this_blk_bio{'C'} = C;
   blk_params.C = C;

%
%  Compute the switching period:
%  -----------------------------
%
   T_switch = 1/f_switch;
   blk_params.T_switch = T_switch;
   this_blk_bio{'T_switch'} = T_switch;

%
%  Compute the minimum inductor current for conducting mode
%  (it is half the inductor current ripple since at this level the
%  output impedance has forced the inductance current toward zero):
%  ----------------------------------------------------------------
%
   I_inductor_min = delta_I_inductor/2;
   this_blk_bio{'I_inductor_min'} = I_inductor_min;

%
%  Compute the maximum output impedance:
%  -------------------------------------
%
   Z_out_max = V_out/I_inductor_min;
   this_blk_bio{'Z_out_max'} = Z_out_max;

%
%  Perform connection checks but only when the block is
%  updating or initializing:
%  -------------------------
%
   sim_status = get_param(bdroot(gcb), 'SimulationStatus');

   perform_cxn_check = ...
      any(strcmp(sim_status, {'updating', 'initializing'}));
   if perform_cxn_check

      i_1_blk = [gcb, '/i_1'];
      input_bond_info = get_adjacent_bond(i_1_blk, 'A', 1);

      input_bond_exists = ~isempty(input_bond_info);
      if input_bond_exists

         input_bond_bio = simbus_bio.factory(input_bond_info{1});
         input_bond_causal_stroke_location = ...
            input_bond_bio{'causal_stroke_location'};

         input_bond_causal_stroke_location_not_A = ...
            (input_bond_causal_stroke_location ~= 'A');
         if input_bond_causal_stroke_location_not_A

            err_str = sprintf('Error in block "%s". A-side bond (input bond) must provide effort (boost converter input voltage in this case). Please make sure that the causal stroke of the input bond is adjacent to the A-side of this boost converter block.', gcb);
            error(err_str);

         end % if input_bond_causal_stroke_location_not_A

      end % if input_bond_exists

      E_1_blk = [gcb, '/E_1'];
      output_bond_info = get_adjacent_bond(E_1_blk, 'B', 4);

      output_bond_exists = ~isempty(output_bond_info);
      if output_bond_exists

         output_bond_bio = simbus_bio.factory(output_bond_info{1});
         output_bond_causal_stroke_location = ...
            output_bond_bio{'causal_stroke_location'};

         output_bond_causal_stroke_location_B = ...
            (output_bond_causal_stroke_location == 'B');
         if output_bond_causal_stroke_location_B

            err_str = sprintf('Error in block "%s". B-side bond (output bond) must provide flow (boost converter output current in this case). Please make sure that the causal stroke of the output bond is NOT adjacent to the B-side of this boost converter block.', gcb);
            error(err_str);

         end % if output_bond_causal_stroke_location_B

      end % if output_bond_exists

   end % if perform_cxn_check

   return;

end % of function "blk_boost_converter_simple".
